OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "New note" : "Nouvelle note",
    "Note is currently saving. Leaving the page will delete all changes!" : "Note en cours d'enregistrement. Quitter la page perdra toutes les modifications !",
    "_%n word_::_%n words_" : ["%n mot","%n mots"],
    "Delete note" : "Supprimer la note",
    "Favorite" : "Favoris",
    "No notes found" : "Aucune note trouvée"
},
"nplurals=2; plural=(n > 1);");
